@@ -73,13 +73,13 @@ class BuildHandler(HandlerClass):
         use_ssl = context.settings.options.docker_ssl_registry
 
         tag = self.data['tag'].lstrip("v")
-        repo, name = ["".join(list(i)[::-1]).replace('/', '_') for i in self.data['name'][::-1].split('/', 1)][::-1]
+        repo, name = ["".join(list(i)[::-1]).replace('/', '_') for i in self.data['name'].lower()[::-1].split('/', 1)][::-1]
 
         if not context.settings.options.docker_registry:
             log.warning("PUSHING TO PUBLIC DOCKER REGISTRY.")
         else:
-            name = "%s/%s" % (repo, name)
-            repo = "%s/%s" % (registry, name)
+            name = ("%s/%s" % (repo, name)).lower()
+            repo = ("%s/%s" % (registry, name)).lower()
 
             try:
                 self.docker.tag(self.data['id'], repo, tag)
@@ -130,7 +130,8 @@ class BuildHandler(HandlerClass):
         log.info("Preparing complete")
 
     def build(self, path):
-        tag = "%s:%s" % (self.data['name'], self.data['tag'].lstrip("v"))
+        tag = ("%s:%s" % (self.data['name'], self.data['tag'].lstrip("v"))).lower()
+
         self.build_log = []
         for line in self.docker.build(path, pull=True, rm=True, forcerm=True, tag=tag):
             chunk = json.loads(line)
